betty.ancestry.place module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.ancestry.place module

Provide the place entity.

final class betty.ancestry.place.Place

  Bases: `ShorthandPluginBase`, `HasLinks`, `HasFileReferences`, `HasNotes`, `HasPrivacy`, `UserFacingEntity`, `Entity`

  A place.

  A place is a physical location on earth. It may be identifiable by GPS coordinates only, or be a well-known city, with names in many languages, imagery, and its own Wikipedia page, or any type of place in between.

  __init__(*, id: str | None = None, names: MutableSequence[Name] | None = None, events: Iterable[Event] | ToManyResolver[Event] | None = None, enclosers: Iterable['Enclosure'] | ToManyResolver['Enclosure'] | None = None, enclosees: Iterable['Enclosure'] | ToManyResolver['Enclosure'] | None = None, notes: Iterable[Note] | ToManyResolver[Note] | None = None, coordinates: Point | None = None, links: MutableSequence[Link] | None = None, privacy: Privacy | None = None, public: bool | None = None, private: bool | None = None, place_type: PlaceType | None = None)
  property coordinates: Point | None

    The place’s coordinates.

  async dump_linked_data(project: Project) → DumpMapping[Dump]

    Dump this instance to JSON-LD.

  enclosees

    A bidirectional *-to-many entity type association.

  enclosers

    A bidirectional *-to-many entity type association.

  events

    A bidirectional *-to-many entity type association.

  property label: Localizable

    The entity’s human-readable label.

  async classmethod linked_data_schema(project: Project) → JsonLdObject

    Define the JSON Schema for `betty.json.linked_data.LinkedDataDumpable.dump_linked_data()`.

  property names: MutableSequence[Name]

    The place’s names.

    The first name is considered the `place label`.

  property place_type: PlaceType

    The type of this place.

  classmethod plugin_label_plural() → Localizable

    The human-readable entity type label, plural.

  property walk_enclosees: Iterator['Enclosure']

    All enclosed places.